[![codecov](https://codecov.io/gh/stefanondisponibile/theboringlibrary/branch/develop/graph/badge.svg?token=8VHJ01UKLX)](https://codecov.io/gh/stefanondisponibile/theboringlibrary)

# theboringlibrary

<p align="center">
  <a href="https://stefanofrassetto.com/theboringlibrary"><img width="200px" src="docs/img/rb.png" alt="TheBoringLibrary"></a>
</p>


## Installation

```bash
pip install theboringlibrary
```

## Usage

From your terminal:

```bash
theboringlibrary
```

Or as a library:

```python
import theboringlibrary as boh

assert boh.do_nothing() is None
```

---

For advance usage see [the official documentation](https://stefanondisponibile.github.io/theboringlibrary/).

